/*
 crcfile:
 
 A CLI utility to do a CRC32 on a file.  This is useful to check that a block of memory you just 
 transferred to/from the monitor is the same as the file on disc.
 
 (c) Matt Evans, April 2005
 */

#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/mman.h>
#include <fcntl.h>
#include <errno.h>

#include "crc.h"

int main(int argc, char *argv[])
{
  int ffd;
  struct stat sb;
  unsigned char *buff;
  u_int32_t length;
  
  if (argc != 2)
  {
    printf("Syntax: %s <filename>\n", argv[0]);
    return 1;
  }
    
  if ((ffd = open(argv[1], O_RDONLY)) < 0)
  {
    printf("Can't open %s (error %d)\n", argv[1], errno);
    return 1;
  }
  
  if (fstat(ffd, &sb) != 0)
  {
    printf("Can't stat %s (error %d)\n", argv[1], errno);
    return 1;
  }
  
  length = sb.st_size;
    
  if ((buff = mmap(0, length, PROT_READ, MAP_PRIVATE, ffd, 0)) == MAP_FAILED)
  {
    printf("Can't map file!\n");
    return 1;
  }
  
  printf("File mapped at %p, len 0x%x\n", buff, length);
  
  crc16_init();
  crc32_init();
  
  printf("CRC16 = 0x%04x\n", crc16_buf(buff, length));
  printf("CRC32 = 0x%08x\n", crc32_buf(buff, length));
  close(ffd); // yawn
  
  return 0;
}
