/*
 Defines for the Amstrad Emailer E2:  The Sharp LH79531 on-chip peripherals and 
 external on-board perhipherals (e.g. the modem, CPLD, SCP).
 
 (c) Matt Evans 25Mar05
 With much help from Ralph Corderoy's notes
 */

//////////////////////////////// On-chip periphs. ////////////////////////////////////////
// UART0
#define UART_BASE     0xffff4000
#define UART_DR       0x0
#define UART_RXSTAT   0x4
#define UART_BR_LCRH  0x8
#define UART_BR_LCRM  0xc
#define UART_BR_LCRL  0x10
#define UART_CON      0x14
#define UART_FLG      0x18
#define UART_MCR      0x1c
#define UART_INTMSK   0x20
#define UART_STAT     0x24
#define UART_INTR     0x28

// PIO
#define PIO_BASE      0xffff4c00
#define PIO_FMUXCTRL1 0xb0
#define PIO_FMUXCTRL2 0xb4

// Reset & Power Control
#define RPC_BASE        0xffff7800
#define RPC_ID          0x4
#define RPC_MACROCLKCTL 0x18
#define RPC_MACROCLKSEL 0x1c

// WDT
#define WDT_BASE     0xffff8000
#define WDT_CTRL     0

// Counter/Timers
#define CT_BASE      0xffff5800
#define CT0_LOAD     0x00
#define CT0_VALUE    0x04
#define CT0_CTRL     0x08
#define CT0_CLEAR    0x12
#define CT1_LOAD     0x20
#define CT1_VALUE    0x24
#define CT1_CTRL     0x28
#define CT1_CLEAR    0x2c
#define CT2_LOAD     0x40
#define CT2_VALUE    0x44
#define CT2_CTRL     0x48
#define CT2_CLEAR    0x4c

// PWM drivers:
#define PWM_BASE     0xffff5000
// Only use PWM_2, for display contrast
#define PWM0_ENB     0x008
#define PWM1_ENB     0x108
#define PWM2_TC      0x200
#define PWM2_DC      0x204
#define PWM2_ENB     0x208
#define PWM2_DIV     0x20c
#define PWM2_SYNC    0x210
#define PWM2_INV     0x214
#define PWM3_ENB     0x308

// LCDC
#define LCDC_BASE     0xffff2000
#define LCDC_PAL      0xffff2200
#define LCDC_EXT_BASE 0xffff2800

///////////////////////////////////////////////////////////////////////////////////////////

// The CPLD (NAND ctrl.).  Is 8bits wide
#define NAND_BASE               0xa0002000
#define NAND_INFO               0
/* Bits 5-0 seem to be some sort of value to ID flash..?  (RC says NOR flash.) */
//#define NAND_UNK 1-4..? What're these for?
#define NAND_CTRL               5
#define  NAND_CTRL_CS_EXT       0x01   /* Verify this! */
#define  NAND_CTRL_UNK1         0x02
#define  NAND_CTRL_CS_INT       0x04   /* Verify this! */
#define  NAND_CTRL_RE           0x08
#define  NAND_CTRL_UNK2         0x10   /* Is one of these the SE spareareaEnable? */
#define  NAND_CTRL_WE           0x20
#define  NAND_CTRL_ALE          0x40
#define  NAND_CTRL_CLE          0x80
// Data and command reg (essentially latched onto D[7:0])
#define NAND_DATA               6
#define  NAND_CMD_RD_L          0x00
#define  NAND_CMD_RD_H          0x01
#define  NAND_CMD_RD_GAPLESS    0x02
#define  NAND_CMD_PAGEPROG      0x10
#define  NAND_CMD_RD_SPARE      0x50
#define  NAND_CMD_BLKERASE      0x60
#define  NAND_CMD_RD_STATUS     0x70
#define  NAND_CMD_INPUT_DATA    0x80
#define  NAND_CMD_RD_ID         0x90
#define  NAND_CMD_ERASE_SUSPEND 0xB0  
#define  NAND_CMD_ERASE_RESUME  0xD0
#define  NAND_CMD_RESET         0xFF
#define NAND_STATUS             7
#define  NAND_STATUS_BUSY       0x01  /* Shared between the SMC socket and on-board chip!  01.. 0x20?*/
#define  NAND_STATUS_SMPRESENT  0x02
// Which one is SMC-Busy?
/* Reg 8 is accessed (0x2e50) by PBL; is it NAND-related though?  CPLD could do misc. GPIO,
   should beep this out.  (Also seems to be wired to USB sys, may bridge to this.)
*/
